## Version 0.0.73

This new version includes an update to the commitbot feature, which now uses a more efficient model for generating commit messages.

### New Features

- The commitbot has been updated to use the gpt-3.5-turbo-16k-0613 model. This model provides the same quality of commit messages as the previous model but at a fraction of the cost (ce91d6b) (Eric Ma)

### Bug Fixes

- No bug fixes in this release.

### Deprecations

- No deprecations in this release.
